@@ -2,13 +2,12 @@
 # Copyright (c) 2001-2003 Upi Tamminen <desaster@dragonlight.fi>
 # See the COPYRIGHT file for more information
 
-# hienoa (0.52) theme validator
+# hienoa (0.53) theme validator
 
 import sys, string
 
 available_formats = [
     'ACTION',
-    'AUTOREPLY',
     'BANNER',
     'CHANNEL_SIGNOFF',
     'CONFIG_TITLE',
@@ -22,6 +21,7 @@ available_formats = [
     'DCC_OFFER',
     'DCC_OFFER_CHAT',
     'DCC_REQUEST',
+    'HILIGHT_NOTIFY',
     'INPUT_PROMPT',
     'INVITE',
     'JOIN',
@@ -60,8 +60,8 @@ available_formats = [
     'STATUS_CHANNEL',
     'STATUS_CHANOP',
     'STATUS_CLOCK',
-    'STATUS_DCC',
     'STATUS_CPU_SAVER',
+    'STATUS_DCC',
     'STATUS_HOLD',
     'STATUS_HOLD_LINES',
     'STATUS_IDLE',
@@ -89,6 +89,7 @@ available_formats = [
     'TOPIC_UNSET',
     'WALLOP',
     'WHO',
+    'WHO_END',
     'WHOIS_AWAY',
     'WHOIS_CHANNELS',
     'WHOIS_END',
@@ -103,7 +104,6 @@ available_formats = [
     'WHOWAS_HEADER',
     'WHOWAS_IRCNAME',
     'WHOWAS_NICK',
-    'WHO_END',
     ]
 
 def validate(filename):
